try_filter: Try to filter a column if a value is provided the the cmd...

Description Usage Arguments Value

View source: R/organization.r

Description

This function filters a specified column within a dataset by a commnd line option.

Usage

1
try_filter(., col, val)

Arguments

.

The dataset

col

The name of the column to filter

val

The value to filter the column by

Value

The dataset where all values in col are val


bnestere/cliplot documentation built on June 7, 2020, 3:04 a.m.