Description Usage Arguments Value
This function filters a specified column within a dataset by a commnd line option.
1 | try_filter(., col, val)
|
. |
The dataset |
col |
The name of the column to filter |
val |
The value to filter the column by |
The dataset where all values in col are val
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.